@@ -12,6 +12,12 @@
 
 import { V220DevfileComponents } from '@devfile/api';
 
+export type GitOauthProvider =
+  | 'github'
+  | 'gitlab'
+  | 'bitbucket'
+  | 'azure-devops';
+
 export interface IPatch {
   op: string;
   path: string;
@@ -47,6 +53,7 @@ export interface IServerConfig {
   timeouts: {
     inactivityTimeout: number;
     runTimeout: number;
+    startTimeout: number;
   };
   cheNamespace: string;
 }
