@@ -21,6 +21,7 @@ import {
 } from '../types';
 import { createError } from './helpers/createError';
 import { CustomObjectAPI, prepareCustomObjectAPI } from './helpers/prepareCustomObjectAPI';
+import { startTimeoutSeconds } from '../../constants/server-config';
 
 const CUSTOM_RESOURCE_DEFINITIONS_API_ERROR_LABEL = 'CUSTOM_RESOURCE_DEFINITIONS_API_ERROR';
 
@@ -110,8 +111,18 @@ export class ServerConfigApiService implements IServerConfigApi {
     return cheCustomResource.spec.components?.dashboard?.headerMessage?.text;
   }
 
+  // getRunningWorkspacesLimit return the maximum number of running workspaces.
+  // See https://github.com/eclipse-che/che-operator/pull/1585 for details.
   getRunningWorkspacesLimit(cheCustomResource: CustomResourceDefinition): number {
-    return cheCustomResource.spec.components?.devWorkspace?.runningLimit || 1;
+    return (
+      cheCustomResource.spec.devEnvironments?.maxNumberOfRunningWorkspacesPerUser ||
+      cheCustomResource.spec.components?.devWorkspace?.runningLimit ||
+      1
+    );
+  }
+
+  getAllWorkspacesLimit(cheCustomResource: CustomResourceDefinition): number {
+    return cheCustomResource.spec.devEnvironments?.maxNumberOfWorkspacesPerUser || -1;
   }
 
   getWorkspaceInactivityTimeout(cheCustomResource: CustomResourceDefinition): number {
@@ -121,4 +132,8 @@ export class ServerConfigApiService implements IServerConfigApi {
   getWorkspaceRunTimeout(cheCustomResource: CustomResourceDefinition): number {
     return cheCustomResource.spec.devEnvironments?.secondsOfRunBeforeIdling || -1;
   }
+
+  getWorkspaceStartTimeout(cheCustomResource: CustomResourceDefinition): number {
+    return cheCustomResource.spec.devEnvironments?.startTimeoutSeconds || startTimeoutSeconds;
+  }
 }
