@@ -14,15 +14,16 @@ import { api } from '@eclipse-che/common';
 import * as k8s from '@kubernetes/client-node';
 import { IUserProfileApi } from '../types';
 import { createError } from './helpers/createError';
+import { CoreV1API, prepareCoreV1API } from './helpers/prepareCoreV1API';
 
 const ERROR_LABEL = 'CORE_V1_API_ERROR';
 const USER_PROFILE_SECRET_NAME = 'user-profile';
 
 export class UserProfileApiService implements IUserProfileApi {
-  private readonly coreV1API: k8s.CoreV1Api;
+  private readonly coreV1API: CoreV1API;
 
   constructor(kc: k8s.KubeConfig) {
-    this.coreV1API = kc.makeApiClient(k8s.CoreV1Api);
+    this.coreV1API = prepareCoreV1API(kc);
   }
 
   async getUserProfile(namespace: string): Promise<api.IUserProfile | undefined> {
