@@ -118,9 +118,12 @@ export type CustomResourceDefinitionSpecDevEnvironments = {
   disableContainerBuildCapabilities?: boolean;
   secondsOfInactivityBeforeIdling?: number;
   secondsOfRunBeforeIdling?: number;
+  startTimeoutSeconds?: number;
   storage?: {
     pvcStrategy?: string;
   };
+  maxNumberOfRunningWorkspacesPerUser: number;
+  maxNumberOfWorkspacesPerUser: number;
 };
 
 export type CustomResourceDefinitionSpecComponents = {
@@ -183,6 +186,11 @@ export interface IServerConfigApi {
    */
   getRunningWorkspacesLimit(cheCustomResource: CustomResourceDefinition): number;
 
+  /**
+   * Returns the total number of workspaces, both stopped and running, that a user can keep.
+   */
+  getAllWorkspacesLimit(cheCustomResource: CustomResourceDefinition): number;
+
   /**
    * Returns the workspace inactivity timeout
    */
@@ -192,6 +200,11 @@ export interface IServerConfigApi {
    * Returns the workspace run timeout
    */
   getWorkspaceRunTimeout(cheCustomResource: CustomResourceDefinition): number;
+
+  /**
+   * Returns the workspace start timeout
+   */
+  getWorkspaceStartTimeout(cheCustomResource: CustomResourceDefinition): number;
 }
 
 export interface IKubeConfigApi {
