@@ -29,10 +29,9 @@ export default function (
     newTitle = `Devfile could not be found in ${sourceUrl}. Applying the default configuration.`;
   } else {
     newTitle = `Devfile found in repo ${sourceUrl} as '${source}'.`;
-  }
-  if (factoryResolverConverted.isConverted) {
-    const devfile = factoryResolverConverted.devfileV2;
-    newTitle += ` Devfile version 1 found, converting it to devfile version ${devfile.schemaVersion}.`;
+    if (factoryResolverConverted.isConverted) {
+      newTitle += ` Devfile version 1 found, converting it to devfile version 2.`;
+    }
   }
   return newTitle;
 }
