@@ -18,8 +18,10 @@ import React from 'react';
 import GetStarted from '..';
 import { FakeStoreBuilder } from '../../../store/__mocks__/storeBuilder';
 import { BrandingData } from '../../../services/bootstrap/branding.constant';
-import { constructWorkspace, Devfile, Workspace } from '../../../services/workspace-adapter';
-import { CheWorkspaceBuilder } from '../../../store/__mocks__/cheWorkspaceBuilder';
+import { constructWorkspace, Workspace } from '../../../services/workspace-adapter';
+import { DevWorkspaceBuilder } from '../../../store/__mocks__/devWorkspaceBuilder';
+import { devfileToDevWorkspace } from '../../../services/workspace-client/devworkspace/converters';
+import devfileApi from '../../../services/devfileApi';
 
 const setWorkspaceQualifiedName = jest.fn();
 const createWorkspaceFromDevfileMock = jest.fn().mockResolvedValue(undefined);
@@ -28,32 +30,25 @@ const startWorkspaceMock = jest.fn().mockResolvedValue(undefined);
 const namespace = 'che';
 const workspaceName = 'wksp-test';
 const dummyDevfile = {
-  apiVersion: '1.0.0',
+  schemaVersion: '2.2.0',
   metadata: {
     name: workspaceName,
+    namespace,
   },
-} as Devfile;
-const workspace = new CheWorkspaceBuilder()
-  .withDevfile(dummyDevfile as che.WorkspaceDevfile)
+} as devfileApi.Devfile;
+const workspace = new DevWorkspaceBuilder()
+  .withName(workspaceName)
   .withNamespace(namespace)
   .build();
 
 jest.mock('../../../store/Workspaces/index', () => {
   return {
     actionCreators: {
-      createWorkspaceFromDevfile:
-        (devfile, namespace, infrastructureNamespace, attributes) =>
-        async (): Promise<Workspace> => {
-          createWorkspaceFromDevfileMock(devfile, namespace, infrastructureNamespace, attributes);
-          return constructWorkspace({
-            id: 'id-wksp-test',
-            attributes,
-            namespace,
-            devfile: dummyDevfile as che.WorkspaceDevfile,
-            temporary: false,
-            status: 'STOPPED',
-          });
-        },
+      createWorkspaceFromDevfile: (devfile, attributes) => async (): Promise<Workspace> => {
+        createWorkspaceFromDevfileMock(devfile, attributes);
+        const devWorkspace = devfileToDevWorkspace(devfile, 'che', false);
+        return constructWorkspace(devWorkspace);
+      },
       startWorkspace: workspace => async (): Promise<void> => {
         startWorkspaceMock(workspace);
       },
@@ -93,15 +88,13 @@ describe('Quick Add page', () => {
 
     await waitFor(() => expect(screen.getByRole('button', { name: 'Dummy Devfile' })).toBeTruthy());
 
-    const devfileButton = screen.getByRole('button', { name: 'Dummy Devfile' });
+    const devfileButton = await screen.findByRole('button', { name: 'Dummy Devfile' });
+    expect(devfileButton).toBeTruthy();
     devfileButton.click();
 
-    expect(createWorkspaceFromDevfileMock).toHaveBeenCalledWith(
-      dummyDevfile,
-      undefined,
-      namespace,
-      { stackName: 'dummyStackName' },
-    );
+    expect(createWorkspaceFromDevfileMock).toHaveBeenCalledWith(dummyDevfile, {
+      stackName: 'dummyStackName',
+    });
   });
 
   it('should have correct masthead when Quick Add tab is active', () => {
@@ -130,13 +123,12 @@ function createFakeStore(): Store {
     .withBranding({
       name: 'test',
     } as BrandingData)
-    .withCheWorkspaces({
+    .withDevWorkspaces({
       workspaces: [workspace],
     })
     .withWorkspaces({
-      workspaceUID: workspace.id,
-      namespace: namespace,
-      workspaceName: workspace.devfile.metadata.name,
+      namespace: workspace.metadata.namespace,
+      workspaceName: workspace.metadata.name,
     })
     .withInfrastructureNamespace([{ name: namespace, attributes: { phase: 'Active' } }], false)
     .build();
