@@ -30,7 +30,6 @@ import * as DevWorkspacesStore from '../../store/Workspaces/devWorkspaces';
 import * as WorkspacesSettingsStore from '../../store/Workspaces/Settings';
 import { ResourceFetcherService } from '../resource-fetcher';
 import { IssuesReporterService, IssueType, WorkspaceData } from './issuesReporter';
-import { CheWorkspaceClient } from '../workspace-client/cheworkspace/cheWorkspaceClient';
 import { DevWorkspaceClient } from '../workspace-client/devworkspace/devWorkspaceClient';
 import { selectDwEditorsPluginsList } from '../../store/Plugins/devWorkspacePlugins/selectors';
 import devfileApi from '../devfileApi';
@@ -50,9 +49,6 @@ export default class Bootstrap {
   @lazyInject(IssuesReporterService)
   private readonly issuesReporterService: IssuesReporterService;
 
-  @lazyInject(CheWorkspaceClient)
-  private readonly cheWorkspaceClient: CheWorkspaceClient;
-
   @lazyInject(DevWorkspaceClient)
   private readonly devWorkspaceClient: DevWorkspaceClient;
 
@@ -329,9 +325,8 @@ export default class Bootstrap {
       this.issuesReporterService.registerIssue(type, error, workspaceData);
     } catch (e) {
       if (e instanceof WorkspaceRunningError) {
-        // workspace is running, redirect to workspace url
-        if (stoppedWorkspace?.ideUrl) {
-          window.location.href = stoppedWorkspace.ideUrl;
+        if (e.workspace.ideUrl) {
+          window.location.href = e.workspace.ideUrl;
           return;
         }
       } else {
