@@ -65,9 +65,6 @@ jest.mock('../../../services/devfileApi/typeguards.ts', () => {
 console.error = jest.fn();
 
 const cheWorkspaceClient = container.get(CheWorkspaceClient);
-jest
-  .spyOn(cheWorkspaceClient.restApiClient, 'provisionKubernetesNamespace')
-  .mockResolvedValue({} as KubernetesNamespace);
 
 const getFactoryResolverSpy = jest.spyOn(cheWorkspaceClient.restApiClient, 'getFactoryResolver');
 
@@ -84,7 +81,6 @@ describe('FactoryResolver store', () => {
 
       const store = new FakeStoreBuilder()
         .withWorkspacesSettings({
-          'che.devworkspaces.enabled': 'true',
           'che.workspace.storage.preferred_type': 'ephemeral',
         })
         .build() as MockStoreEnhanced<
@@ -117,12 +113,7 @@ describe('FactoryResolver store', () => {
 
       getFactoryResolverSpy.mockResolvedValueOnce(resolver);
 
-      const store = new FakeStoreBuilder()
-        .withWorkspacesSettings({
-          'che.devworkspaces.enabled': 'true',
-          'che.workspace.storage.preferred_type': 'ephemeral',
-        })
-        .build() as MockStoreEnhanced<
+      const store = new FakeStoreBuilder().build() as MockStoreEnhanced<
         AppState,
         ThunkDispatch<AppState, undefined, factoryResolverStore.KnownAction>
       >;
