@@ -12,20 +12,10 @@
 
 import { createSelector } from 'reselect';
 import { AppState } from '../..';
-import * as storageTypesService from '../../../services/storageTypes';
-import { isDevworkspacesEnabled } from '../../../services/helpers/devworkspace';
 
 const selectState = (state: AppState) => state.workspacesSettings;
 export const selectWorkspacesSettingsState = selectState;
 
 export const selectWorkspacesSettings = createSelector(selectState, state => state.settings);
 
-export const selectAvailableStorageTypes = createSelector(selectWorkspacesSettings, settings =>
-  storageTypesService.getAvailable(settings),
-);
-
 export const selectWorkspacesSettingsError = createSelector(selectState, state => state.error);
-
-export const selectDevworkspacesEnabled = createSelector(selectState, state =>
-  isDevworkspacesEnabled(state?.settings || {}),
-);
