@@ -10,7 +10,6 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import { V1alpha2DevWorkspaceSpecTemplate } from '@devfile/api';
 import devfileApi from '../../services/devfileApi';
 import getRandomString from '../../services/helpers/random';
 import { DevWorkspaceStatus } from '../../services/helpers/types';
@@ -70,7 +69,12 @@ export class DevWorkspaceBuilder {
     return this;
   }
 
-  withTemplate(template: V1alpha2DevWorkspaceSpecTemplate): DevWorkspaceBuilder {
+  withSpec(spec: Partial<devfileApi.DevWorkspaceSpec>): DevWorkspaceBuilder {
+    Object.assign(this.workspace.spec, spec);
+    return this;
+  }
+
+  withTemplate(template: devfileApi.DevWorkspaceSpecTemplate): DevWorkspaceBuilder {
     this.workspace.spec.template = template;
     return this;
   }
