@@ -17,39 +17,35 @@ import * as BrandingStore from './Branding';
 import * as ClusterConfig from './ClusterConfig';
 import * as ClusterInfo from './ClusterInfo';
 import * as DevfileRegistriesStore from './DevfileRegistries';
-import * as CheDockerConfigStore from './DockerConfig/che';
-import * as DwDockerConfigStore from './DockerConfig/dw';
+import * as DockerConfigStore from './DockerConfig';
 import * as FactoryResolverStore from './FactoryResolver';
 import * as InfrastructureNamespacesStore from './InfrastructureNamespaces';
 import * as PluginsStore from './Plugins/chePlugins';
 import * as SanityCheckStore from './SanityCheck';
 import * as DwPluginsStore from './Plugins/devWorkspacePlugins';
 import * as DwServerConfigStore from './ServerConfig';
-import * as UserPreferences from './UserPreferences';
 import * as UserProfileStore from './UserProfile';
 import * as WorkspacesStore from './Workspaces';
-import * as CheWorkspacesStore from './Workspaces/cheWorkspaces';
 import * as DevWorkspacesStore from './Workspaces/devWorkspaces';
 import * as WorkspacesSettingsStore from './Workspaces/Settings';
+import * as GitOauthConfigStore from './GitOauthConfig';
 
 // the top-level state object
 export interface AppState {
   bannerAlert: BannerAlertStore.State;
   branding: BrandingStore.State;
-  cheDockerConfig: CheDockerConfigStore.State;
-  cheWorkspaces: CheWorkspacesStore.State;
   clusterConfig: ClusterConfig.State;
   clusterInfo: ClusterInfo.State;
   devWorkspaces: DevWorkspacesStore.State;
   devfileRegistries: DevfileRegistriesStore.State;
-  dwDockerConfig: DwDockerConfigStore.State;
+  gitOauthConfig: GitOauthConfigStore.State;
+  dockerConfig: DockerConfigStore.State;
   dwPlugins: DwPluginsStore.State;
   dwServerConfig: DwServerConfigStore.State;
   factoryResolver: FactoryResolverStore.State;
   infrastructureNamespaces: InfrastructureNamespacesStore.State;
   plugins: PluginsStore.State;
   sanityCheck: SanityCheckStore.State;
-  userPreferences: UserPreferences.State;
   userProfile: UserProfileStore.State;
   workspaces: WorkspacesStore.State;
   workspacesSettings: WorkspacesSettingsStore.State;
@@ -58,20 +54,18 @@ export interface AppState {
 export const reducers = {
   bannerAlert: BannerAlertStore.reducer,
   branding: BrandingStore.reducer,
-  cheDockerConfig: CheDockerConfigStore.reducer,
-  cheWorkspaces: CheWorkspacesStore.reducer,
   clusterConfig: ClusterConfig.reducer,
   clusterInfo: ClusterInfo.reducer,
   devWorkspaces: DevWorkspacesStore.reducer,
   devfileRegistries: DevfileRegistriesStore.reducer,
-  dwDockerConfig: DwDockerConfigStore.reducer,
+  gitOauthConfig: GitOauthConfigStore.reducer,
+  dockerConfig: DockerConfigStore.reducer,
   dwPlugins: DwPluginsStore.reducer,
   dwServerConfig: DwServerConfigStore.reducer,
   factoryResolver: FactoryResolverStore.reducer,
   infrastructureNamespaces: InfrastructureNamespacesStore.reducer,
   plugins: PluginsStore.reducer,
   sanityCheck: SanityCheckStore.reducer,
-  userPreferences: UserPreferences.reducer,
   userProfile: UserProfileStore.reducer,
   workspaces: WorkspacesStore.reducer,
   workspacesSettings: WorkspacesSettingsStore.reducer,
